@@ -3,7 +3,7 @@ package OpenAPI::Modern::Utilities;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Internal utilities and common definitions for OpenAPI::Modern
 
-our $VERSION = '0.111';
+our $VERSION = '0.112';
 
 use 5.020;
 use strictures 2;
@@ -51,7 +51,7 @@ use constant SUPPORTED_OAD_VERSIONS => [ '3.0.4', '3.1.2', '3.2.0' ];
 # in most things, e.g. schemas, we only use major.minor as the version number
 # we don't actually support OAS 3.0.x, but we will bundle its schema so it can be more easily used
 # for validating v3.0 OADs
-use constant OAS_VERSIONS => [ '3.0', map s/^\d+\.\d+\K\.\d+$//r, SUPPORTED_OAD_VERSIONS->@* ];
+use constant OAS_VERSIONS => [ map s/^\d+\.\d+\K\.\d+$//r, SUPPORTED_OAD_VERSIONS->@* ];
 
 # see https://spec.openapis.org/#openapi-specification-schemas for the latest links
 # these are updated automatically at build time via 'update-schemas'
@@ -87,7 +87,6 @@ use constant OAS_VOCABULARY => {
 
 # an OpenAPI schema and JSON Schema dialect which prohibit unknown keywords
 use constant STRICT_METASCHEMA => {
-  '3.0' => '',
   3.1 => 'https://raw.githubusercontent.com/karenetheridge/OpenAPI-Modern/master/share/3.1/strict-schema.json',
   3.2 => 'https://raw.githubusercontent.com/karenetheridge/OpenAPI-Modern/master/share/3.2/strict-schema.json',
 };
@@ -181,7 +180,7 @@ OpenAPI::Modern::Utilities - Internal utilities and common definitions for OpenA
 
 =head1 VERSION
 
-version 0.111
+version 0.112
 
 =head1 SYNOPSIS
 
